# Note from upstream:
# the SDL playback plugin is now deprecated in favour of the openGL playback plugin.
# For one thing the program will crash if you use the SDL plugin and projectM plugin at the same time.
# If you have both SDL 1 and SDL 2 installed, LiVES will detect both, since it will use SDL2 for projectM and SDL1 for the SDL playback plugin.
# Use 'SDL2' and 'projectM' together.
%bcond_without SDL2_projectM

# LiVES is not ready for FFMpeg-5* yet
%if 0%{?mageia} > 8
%bcond_with ffmpeg
%endif

%define major		0
%define libname		%mklibname weed %{major}
%define develname	%mklibname weed -d

Summary:	Linux Video Editing System
Name:		lives
Version:	3.2.0
Release:	%mkrel 9
License:	GPLv3+
Group:		Video/Editors and Converters
URL:		http://lives-video.com/
Source0:	http://lives-video.com/releases/LiVES-%{version}.tar.bz2
Patch1:		lives-3.2.0-opencv4.patch

BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(fftw3f)
BuildRequires:	pkgconfig(frei0r)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glee)
BuildRequires:	pkgconfig(glib-2.0) >= 2.14.0
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:	pkgconfig(libavc1394)
%if %{with ffmpeg}
BuildRequires:	pkgconfig(libavcodec) >= 53.0.0
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
%endif
BuildRequires:	pkgconfig(libdv)
BuildRequires:	pkgconfig(liboil-0.3) >= 0.3.9
BuildRequires:	pkgconfig(libpng) > 1.2.0
BuildRequires:	pkgconfig(libpulse) >= 0.9.14
BuildRequires:	pkgconfig(libraw1394)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libunicap)
BuildRequires:	pkgconfig(libvisual-0.4) >= 0.4.0
BuildRequires:	pkgconfig(mjpegtools) >= 1.6.2
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(opencv) >= 2.3.1
BuildRequires:	pkgconfig(schroedinger-1.0)
BuildRequires:  pkgconfig(libtirpc)
%if %{with SDL2_projectM}
BuildRequires:	pkgconfig(libprojectM)
BuildRequires:	pkgconfig(sdl2)
%endif
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xrender)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	bison
BuildRequires:	ladspa-devel
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(jack)
BuildRequires:	libv4l-devel
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(fftw3)
%if %{with ffmpeg}
Requires:	ffmpeg
%endif
Requires:	mplayer sox imagemagick
Requires:	cdrecord-cdda2wav
Requires:	xset
Requires:	libvisual-plugins
#This are not mandatory dependencies according to README
Recommends:	cdrkit-icedax
Recommends:	dvgrab
Recommends:	frei0r
Recommends:	lame
Recommends:	ladspa
Recommends:	mkvtoolnix
Recommends:	mpv
Recommends:	vorbis-tools
Recommends:	x264
Recommends:	yt-dlp

%description
The Linux Video Editing System (LiVES) is intended to be a simple yet powerful
video effects and editing system.  It uses common tools for most of its work
(mplayer, ImageMagick, GTK+, sox).

%package -n %{libname}
Summary:	Linux Video Editing System - shared libs
Group:		Video/Editors and Converters

%description -n %{libname}
This package contains shared libs for LiVES.

%package -n %{develname}
Summary:	Linux Video Editing System - Development files
Group:		Video/Editors and Converters
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains development files needed to build LiVES plugins.

%prep
%autosetup -p1

# update manually the library paths in libweed/*.pc files on a 64 bit system
%ifarch x86_64 aarch64
sed -i 's|\${exec_prefix}/lib|\${exec_prefix}/lib64|' libweed/*.pc
%endif

%build
%define _disable_ld_no_undefined 1
export CFLAGS="%{optflags} -std=gnu17"
%configure \
           %if %{without SDL2_projectM}
           --disable-sdl2 --disable-projectM \
           %endif
           %if %{without ffmpeg}
           --disable-ffmpeg \
           %endif
           --enable-threads=posix
%make_build CPPFLAGS="$(pkg-config --cflags libtirpc)"

%install
%make_install

%find_lang %{name}

rm -fr %{buildroot}%{_datadir}/doc
rm -f %{buildroot}%{_datadir}/pixmaps/%{name}.xpm

# fix symlink
rm -rf %{buildroot}%{_bindir}/%{name}
ln -s %{_bindir}/%{name}-exe %{buildroot}%{_bindir}/%{name}

# don't ship .a or .la
find %{buildroot} -name '*.a' -delete
find %{buildroot} -name '*.la' -delete

# python shebang
%py3_shebang_fix \
  %{buildroot}%{_libdir}/lives/plugins/encoders/* \
  %{buildroot}%{_bindir}/lives_*

%files -f %{name}.lang
%doc AUTHORS C* docs/*.txt FEATURES GETTING*
%doc NEWS OMC/*.txt README RFX/*
%{_bindir}/*
%{_datadir}/%{name}
%{_libdir}/%{name}
%{_datadir}/applications/LiVES.desktop
%{_datadir}/app-install/icons/lives.png
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/lives.png

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/weed
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Wed Apr 30 2025 daviddavid <daviddavid> 3.2.0-9.mga10
+ Revision: 2180101
- fix build with GCC 15 using 'std=gnu17'
- rebuild for new libtheora 1.2.0

* Sat Sep 14 2024 wally <wally> 3.2.0-8.mga10
+ Revision: 2096375
- properly fix python shebangs
- rebuild for opencv 4.10.0

* Sun May 07 2023 daviddavid <daviddavid> 3.2.0-7.mga9
+ Revision: 1956033
- rebuild for new mjpegtools 2.2.1
- switch to yt-dlp

* Wed Nov 16 2022 daviddavid <daviddavid> 3.2.0-5.mga9
+ Revision: 1908194
- disable FFMpeg in Mageia 9 for now (not ready for FFMpeg-5* yet)
+ ghibo <ghibo>
- Rebuild against opencv 4.6.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Mon Dec 27 2021 wally <wally> 3.2.0-2.mga9
+ Revision: 1764539
- rebuild for opencv 4.5.5

* Fri Apr 23 2021 daviddavid <daviddavid> 3.2.0-1.mga9
+ Revision: 1718129
- new version: 3.2.0
- remove merged upstream patch
- fix build with current opencv4

* Thu Nov 26 2020 tv <tv> 3.0.2-8.mga8
+ Revision: 1649481
- fix building with libtirpc

* Fri Oct 30 2020 joequant <joequant> 3.0.2-7.mga8
+ Revision: 1640663
- rebuild for opencv

* Sun Jun 28 2020 joequant <joequant> 3.0.2-6.mga8
+ Revision: 1599914
- fix gcc10 build

* Fri Jun 05 2020 daviddavid <daviddavid> 3.0.2-5.mga8
+ Revision: 1590526
- fix library paths in all libweed/*.pc files for 64 bit system

* Fri Jun 05 2020 daviddavid <daviddavid> 3.0.2-4.mga8
+ Revision: 1590522
- switch to sdl2 needed for projectM
- switch to upstream patch for opencv 4 support
- fix build with gcc10
- rebuild for new libprojectm 3.1.3

* Wed Feb 19 2020 umeabot <umeabot> 3.0.2-3.mga8
+ Revision: 1544567
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 3.0.2-2.mga8
+ Revision: 1483327
- replace deprecated %%configure2_5x
+ daviddavid <daviddavid>
- add patch to fix build with opencv 4.2.0
- rebuild for new opencv 4.2.0

* Fri Nov 15 2019 zezinho <zezinho> 3.0.2-1.mga8
+ Revision: 1460752
- new version 3
- add all recommended helpers
- enable frei0r
- enable ProjectM

* Wed Jan 09 2019 zezinho <zezinho> 2.10.2-1.mga7
+ Revision: 1353834
- new bugfix version 2.10.2

* Tue Dec 25 2018 zezinho <zezinho> 2.10.1-1.mga7
+ Revision: 1344899
- new version 2.10.1
- new version 2.10.0
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Fri Apr 27 2018 daviddavid <daviddavid> 2.8.9-4.mga7
+ Revision: 1222776
- rebuild for new ffmpeg 4.0

* Fri Apr 13 2018 daviddavid <daviddavid> 2.8.9-2.mga7
+ Revision: 1218276
- rebuild for new opencv 3.4.1

* Thu Mar 15 2018 zezinho <zezinho> 2.8.9-1.mga7
+ Revision: 1209686
- new version 2.8.9

* Sun Mar 11 2018 zezinho <zezinho> 2.8.8-1.mga7
+ Revision: 1208249
- new version 2.8.8

* Mon Feb 26 2018 daviddavid <daviddavid> 2.8.7-2.mga7
+ Revision: 1205274
- remove no more needed BR libpth-devel

* Thu Sep 21 2017 zezinho <zezinho> 2.8.7-1.mga7
+ Revision: 1156741
- new version

* Tue May 02 2017 akien <akien> 2.8.4-4.mga6
+ Revision: 1098364
- Rebuild for ffmpeg 3.3

* Fri Mar 10 2017 akien <akien> 2.8.4-3.mga6
+ Revision: 1091625
- Rebuild for v4l-utils 1.12.3

* Sat Jan 21 2017 zezinho <zezinho> 2.8.4-2.mga6
+ Revision: 1082682
- rebuild for ffmpeg 3.2.x

* Mon Jan 16 2017 zezinho <zezinho> 2.8.4-1.mga6
+ Revision: 1082098
- new bugfix version 2.8.4

* Mon Jan 02 2017 zezinho <zezinho> 2.8.3-1.mga6
+ Revision: 1079808
- new version

* Tue Nov 29 2016 zezinho <zezinho> 2.8.2-1.mga6
+ Revision: 1071006
- new version

* Mon Oct 24 2016 zezinho <zezinho> 2.8.1-1.mga6
+ Revision: 1063394
- new version with security fixes for multiusers systems

* Sat Oct 15 2016 zezinho <zezinho> 2.8.0-2.mga6
+ Revision: 1060841
- requires from now ffmpeg instead of mencoder according to upstream

* Fri Sep 09 2016 zezinho <zezinho> 2.8.0-1.mga6
+ Revision: 1051081
- change icon path
- new bugfix version

* Wed May 18 2016 shlomif <shlomif> 2.6.3-1.mga6
+ Revision: 1016598
- Fix build due to a missing #include
+ zezinho <zezinho>
- new version

* Tue Mar 29 2016 zezinho <zezinho> 2.6.2-1.mga6
+ Revision: 996369
- new version

* Tue Mar 15 2016 daviddavid <daviddavid> 2.6.0-3.mga6
+ Revision: 990911
- rebuild with schroedinger without .la files

* Mon Feb 15 2016 luigiwalser <luigiwalser> 2.6.0-2.mga6
+ Revision: 961523
- rebuild for mjpegtools

* Mon Feb 01 2016 zezinho <zezinho> 2.6.0-1.mga6
+ Revision: 930591
- new version

* Mon Jan 25 2016 zezinho <zezinho> 2.4.8-1.mga6
+ Revision: 927351
- new version

* Mon Jan 18 2016 zezinho <zezinho> 2.4.7-1.mga6
+ Revision: 925478
- new version

* Sat Dec 19 2015 zezinho <zezinho> 2.4.6-1.mga6
+ Revision: 912144
- new version

* Wed Dec 02 2015 zezinho <zezinho> 2.4.5-1.mga6
+ Revision: 907748
- new version 2.4.5

* Sat Nov 28 2015 zezinho <zezinho> 2.4.4-1.mga6
+ Revision: 906800
- build witout OSC for now
- new version 2.4.4

* Sun Feb 08 2015 alexl <alexl> 2.2.7-1.mga5
+ Revision: 814170
- version 2.2.7 without crash (mga#15070)
- desktop file with GenericName and Comment
- cleanup spec

* Fri Nov 14 2014 akien <akien> 2.2.6-5.mga5
+ Revision: 797107
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 2.2.6-4.mga5
+ Revision: 744450
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.6-3.mga5
+ Revision: 681964
- Mageia 5 Mass Rebuild

* Tue Aug 26 2014 luigiwalser <luigiwalser> 2.2.6-2.mga5
+ Revision: 668369
- rebuild

* Mon Aug 18 2014 fwang <fwang> 2.2.6-1.mga5
+ Revision: 665021
- 2.2.6

* Mon Oct 21 2013 umeabot <umeabot> 2.0.6-2.mga4
+ Revision: 540926
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 fwang <fwang> 2.0.6-1.mga4
+ Revision: 494553
- new version 2.0.6

* Mon Jul 15 2013 fwang <fwang> 2.0.5-2.mga4
+ Revision: 454428
- more ffmpeg 2.0 patches
- try build with recent ffmpeg
- rebuild for new ffmpeg

* Mon Jun 17 2013 fwang <fwang> 2.0.5-1.mga4
+ Revision: 444026
- new version 2.0.5

* Mon Jun 03 2013 fwang <fwang> 2.0.4-5.mga4
+ Revision: 436007
- rebuild for new libpng

* Fri May 24 2013 fwang <fwang> 2.0.4-1.mga4
+ Revision: 425886
- new version 2.0.4

* Wed Apr 17 2013 dams <dams> 2.0.3-1.mga3
+ Revision: 410294
- new version 2.0.3

* Sat Jan 12 2013 umeabot <umeabot> 1.8.0-3.mga3
+ Revision: 358886
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 1.8.0-2.mga3
+ Revision: 341680
- rebuild for new ffmpeg

* Mon Dec 17 2012 fwang <fwang> 1.8.0-1.mga3
+ Revision: 331898
- fix str fmt
- new version 1.8.0

* Mon Oct 22 2012 fwang <fwang> 1.6.4-1.mga3
+ Revision: 309077
- update rpm group
- new version 1.6.4
- new version 1.6.3
- new version 1.6.2
- more br

* Mon Apr 16 2012 fwang <fwang> 1.6.1-3.mga2
+ Revision: 231015
- add more br

* Mon Apr 16 2012 fwang <fwang> 1.6.1-2.mga2
+ Revision: 231000
- add upstream patch on incorrect usage of brackets, to try fixing bug#5413
+ wally <wally>
- fix lives symlink

* Sun Feb 05 2012 zezinho <zezinho> 1.6.1-1.mga2
+ Revision: 205038
- fix build
- new version 1.6.1

* Fri Jan 13 2012 dams <dams> 1.4.9-1.mga2
+ Revision: 195488
- new version 1.4.9
- rediff patch

* Thu Dec 01 2011 fwang <fwang> 1.4.8-1.mga2
+ Revision: 174700
- fix str fmt
- new version 1.4.8

* Mon Nov 14 2011 dams <dams> 1.4.7-1.mga2
+ Revision: 167442
- new version 1.4.7
+ fwang <fwang>
- new version 1.4.5

* Mon Jul 18 2011 fwang <fwang> 1.4.4-2.mga2
+ Revision: 125816
- rebuild for new mjpegtools

* Sat Jun 18 2011 ahmad <ahmad> 1.4.4-1.mga2
+ Revision: 109346
- Drop xmms requires (it doesn't exist in Mageia)
- Drop gdk-pixbuf-loaders requires, it depends on old gnome libs
- Don't ship .a/.la
- Drop old/unneeded scriptlets
- imported package lives


* Tue Jun 14 2011 Funda Wang <fwang@mandriva.org> 1.4.4-1mdv2011.0
+ Revision: 685117
- drop merged patch
- update to new version 1.4.4

* Mon Jun 13 2011 Funda Wang <fwang@mandriva.org> 1.4.3-1
+ Revision: 684573
- new version 1.4.3

* Tue May 24 2011 Götz Waschk <waschk@mandriva.org> 1.4.2-3
+ Revision: 678153
- really rebuild for new mjpegtools

* Tue May 24 2011 Götz Waschk <waschk@mandriva.org> 1.4.2-2
+ Revision: 678133
- rebuild for new mjpegtools

* Sun Apr 03 2011 Funda Wang <fwang@mandriva.org> 1.4.2-1
+ Revision: 649982
- fix build with kernel 2.6.38
- New version 1..4.2

* Mon Feb 28 2011 Funda Wang <fwang@mandriva.org> 1.4.0-2
+ Revision: 640873
- rebuild

* Sat Feb 19 2011 Funda Wang <fwang@mandriva.org> 1.4.0-1
+ Revision: 638654
- new version 1.4.0

* Mon Jan 17 2011 Lonyai Gergely <aleph@mandriva.org> 1.3.10-1
+ Revision: 631163
- 1.3.10

* Tue Aug 03 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.3.4-1mdv2011.0
+ Revision: 565271
- update to 1.3.4

* Wed Apr 07 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.3.2-1mdv2010.1
+ Revision: 532842
- new release 1.3.2

* Sat Feb 27 2010 Funda Wang <fwang@mandriva.org> 1.2.1-1mdv2010.1
+ Revision: 512334
- update to new version 1.2.1

* Mon Feb 22 2010 Frederik Himpe <fhimpe@mandriva.org> 1.2.0-1mdv2010.1
+ Revision: 509632
- update to new version 1.2.0

* Tue Dec 29 2009 Funda Wang <fwang@mandriva.org> 1.1.8-1mdv2010.1
+ Revision: 483226
- new version 1.1.8

* Mon Dec 28 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.7-1mdv2010.1
+ Revision: 483092
- update to new version 1.1.7

* Mon Nov 16 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.6-1mdv2010.1
+ Revision: 466654
- update to new version 1.1.6

* Thu Nov 12 2009 Ahmad Samir <ahmadsamir@mandriva.org> 1.1.5-2mdv2010.1
+ Revision: 465168
- Add patch to fix lives -> lives-exe symlink (bug #55404)

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 1.1.5-1mdv2010.1
+ Revision: 462598
- update to new version 1.1.5

* Mon Sep 28 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.3-1mdv2010.0
+ Revision: 450654
- update to new version 1.0.3

* Sun Sep 13 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.2-1mdv2010.0
+ Revision: 438612
- update to new version 1.0.2

* Thu Sep 10 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.1-1mdv2010.0
+ Revision: 437099
- update to new version 1.0.1

* Thu Jul 23 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.0-1mdv2010.0
+ Revision: 398989
- Update to new version 1.0.0
- Remove desktop file patch: not needed anymore

* Wed Jun 03 2009 Frederik Himpe <fhimpe@mandriva.org> 0.9.9.9-1mdv2010.0
+ Revision: 382513
- Updated to new version 0.9.9.9
- Remove ldconfig patch: fixed upstream

* Fri May 01 2009 Funda Wang <fwang@mandriva.org> 0.9.9.8-1mdv2010.0
+ Revision: 369839
- disable ldconfig after installing
- New version 0.9.9.8

* Sat Feb 07 2009 Funda Wang <fwang@mandriva.org> 0.9.9.6-1mdv2009.1
+ Revision: 338421
- new version 0.9.9.6
- update url

* Wed Dec 17 2008 Funda Wang <fwang@mandriva.org> 0.9.9.5-1mdv2009.1
+ Revision: 315085
- add file list
- disable undefined
- BR celt
- BR sample rate
- New version 0.9.9.5
- rediff desktop patch
- New version 0.9.9.1

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Fri May 16 2008 Funda Wang <fwang@mandriva.org> 0.9.8.12-1mdv2009.0
+ Revision: 208188
- update to new version 0.9.8.12

* Fri May 16 2008 Funda Wang <fwang@mandriva.org> 0.9.8.11-1mdv2009.0
+ Revision: 208027
- update to new version 0.9.8.11

* Sun Mar 09 2008 Funda Wang <fwang@mandriva.org> 0.9.8.8-1mdv2008.1
+ Revision: 182959
- New version 0.9.8.8

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 28 2007 Funda Wang <fwang@mandriva.org> 0.9.8.7-1mdv2008.1
+ Revision: 138893
- fix desktop item icon ext
- New version 0.9.8.7

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Jul 19 2007 Austin Acton <austin@mandriva.org> 0.9.8.6-2mdv2008.0
+ Revision: 53439
- totally redo buildrequires and requires

* Sat Jul 14 2007 Funda Wang <fwang@mandriva.org> 0.9.8.6-1mdv2008.0
+ Revision: 51982
- BR gpm-devel
- fix desktop file
- New version

* Wed Jun 13 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 0.9.8.5-2mdv2008.0
+ Revision: 38815
- Added missing BuildRequires for desktop-file-utils.
- Removed old menu, switch to freedesktop icon scheme.
- Cleanups.

  + Jérôme Soyer <saispo@mandriva.org>
    - New release

* Tue May 29 2007 Funda Wang <fwang@mandriva.org> 0.9.8.4-2mdv2008.0
+ Revision: 32313
- Rebuild against directfb 1.0


* Sun Apr 01 2007 Jérôme Soyer <saispo@mandriva.org> 0.9.8.4-1mdv2007.1
+ Revision: 150144
- New release

* Wed Feb 28 2007 Götz Waschk <waschk@mandriva.org> 0.9.8.2-2mdv2007.1
+ Revision: 127257
- fix build on x86_64

  + Jérôme Soyer <saispo@mandriva.org>
    - Fix Build
    - New release 0.9.8.2

  + Lenny Cartier <lenny@mandriva.com>
    - Import lives

* Mon Sep 04 2006 Emmanuel Andry <eandry@mandriva.org> 0.9.5-3mdv2007.0
- xdg menu

* Sun Jun 11 2006 Austin Acton <austin@mandriva.org> 0.9.5-2mdv2007.0
- rebuild for libvisual
- mkrel

* Sun Jan 01 2006 Austin Acton <austin@mandriva.org> 0.9.5-1mdk
- 0.9.5 final

* Fri Nov 25 2005 Austin Acton <austin@mandriva.org> 0.9.5-0.pre5.2mdk
- Rebuild

* Sat Oct 01 2005 Austin Acton <austin@mandriva.org> 0.9.5-0.pre5.1mdk
- pre5

* Sun Aug 14 2005 Götz Waschk <waschk@mandriva.org> 0.9.5-0.pre4.2mdk
- rebuild for new mjpegtools

* Thu Jul 28 2005 Austin Acton <austin@mandriva.org> 0.9.5-0.pre4.1mdk
- 0.9.5pre4

* Tue Apr 19 2005 Austin Acton <austin@mandriva.org> 0.9.5-0.pre3.1mdk
- 0.9.5pre3

* Mon Mar 28 2005 Austin Acton <austin@mandrake.org> 0.9.5-0.pre2.2.1mdk
- 0.9.5pre2.2

* Tue Jan 25 2005 Austin Acton <austin@mandrake.org> 0.9.5-0.pre1-1mdk
- 0.9.5pre1

* Wed Jan 12 2005 Michael Scherer <misc@mandrake.org> 0.9.1-3mdk
- Rebuild to remove deps on python2.3, thanks to Fabien Illide

* Sat Dec 11 2004 Austin Acton <austin@mandrake.org> 0.9.1-2mdk
- tidy spec
- add missing doc files and icons (thanks to author)
- buildrequires bison and SDL/mjpegtools-devel
- build with libvisual support on post-10.1
- use ~ as default load/save dir

* Wed Dec 08 2004 Austin Acton <austin@mandrake.org> 0.9.1-1mdk
- 0.9.1
- configure 2.5
- source URL

* Thu Aug 19 2004 Austin Acton <austin@mandrake.org> 0.9.1-0.pre5.2mdk
- fix plugins location

* Thu Aug 19 2004 Austin Acton <austin@mandrake.org> 0.9.1-0.pre5.1mdk
- 0.9.1pre5

* Thu Aug 05 2004 Austin Acton <austin@mandrake.org> 0.9.1-0.pre4.1mdk
- 0.9.1pre4

* Mon Jul 26 2004 Austin Acton <austin@mandrake.org> 0.9.1-0.pre3.1mdk
- 0.9.1pre3

* Wed May 05 2004 Austin Acton <austin@mandrake.org> 0.9.0-0.pre1.1mdk
- 0.9.0pre1

